@@ -7,7 +7,16 @@ import logging
 import traceback
 import random
 from pgzero.actor import Actor
-from fzq_scnu import constants, Input
+from fzq_scnu import Input
+try:
+    # 图形化编程软件的路径
+    sys.path.append('.\\resources\\assets\\class\\emulator_files\\')
+    import constants
+except Exception:
+    # 用于测试的个人路径
+    # from fzq_scnu.fzrunner import files_path
+    sys.path.append('C:\\Users\\86137\\Documents\\python_code\\fzq_test\\emulator_files\\')
+    import constants
 '''
 已有background_rect为Rect((200, 6), (900, 650))
 红外被遮挡（可利用rect碰撞,目前使用颜色检测），还有设置按钮切换左右红外未写
