@@ -16,7 +16,7 @@ from pgzero import loaders
 from pgzero.screen import Screen
 from pgzero.actor import Actor
 from pgzero.rect import Rect
-from fzq_scnu import fzgpio, fzshijue1, tools, constants, levels, Input
+from fzq_scnu import fzgpio, fzshijue1, tools, Input
 # --------------------------------------------------------------------------------------------------------
 # 控制运行的标志，空字符为不运行，非空字符为运行
 run = ''
@@ -33,6 +33,31 @@ class Update(fzgpio.Mecanum_wheel):
         self.py_image = 'None'
         self.actor = Actor(LEVEL.actor[0])
         self.actor.pos = (LEVEL.actor[1])
+        self.actor_small_rect = Rect((self.actor.left + 10, self.actor.top + 10),
+                                     (self.actor.width - 20, self.actor.height - 20))
+        self.actor_big_rect = Rect((self.actor.left - 10, self.actor.top - 10),
+                                   (self.actor.width + 20, self.actor.height + 20))
+        # 积分
+        self.score = 0
+        self.stars = []
+        # 加载level里面的stars为actor类
+        if len(LEVEL.level[3]) >= 1:
+            for i in range(len(LEVEL.level[3][1])):
+                self.stars.append(Actor(LEVEL.level[3][0]))  # 用于存放所有星星对象的列表
+            self.stars_pos = [p for p in LEVEL.level[3][1]]
+            for num, ac in enumerate(self.stars):
+                ac.pos = self.stars_pos[num]  # 给每个对象配置中心坐标
+        else:
+            self.stars = []
+        # 加载level里面的markers为actor类
+        if len(LEVEL.level[4]) >= 1:
+            self.markers = [Actor(a[0]) for a in LEVEL.level[4]]  # 用于存放所有标志物对象的列表
+            self.markers_pos = [(a[1]) for a in LEVEL.level[4]]
+            self.markers_front_view = [a[2] for a in LEVEL.level[4]]
+            for num, ac in enumerate(self.markers):
+                ac.pos = self.markers_pos[num]  # 给每个对象配置中心坐标
+        else:
+            self.markers = []
 
     # 定义绘制文本的方法
     @staticmethod
@@ -51,13 +76,14 @@ class Update(fzgpio.Mecanum_wheel):
         screen.blit(LEVEL.level[0], LEVEL.level[1])
         screen.blit(LEVEL.racetrack[0], LEVEL.racetrack[1])
         screen.blit(LEVEL.interface[0], LEVEL.interface[1])
-        if len(LEVEL.others) >= 2:
-            for other in range(len(LEVEL.others)):
-                screen.blit(LEVEL.others[other][0], LEVEL.others[other][1])
-        elif len(LEVEL.others) == 1:
-            screen.blit(LEVEL.others[0][0], LEVEL.others[0][1])
-        else:
-            pass
+        # 绘制所有星星对象，用于积分
+        if self.stars:
+            for st in self.stars:
+                st.draw()
+        # 绘制所有标志物对象，用于视觉
+        if self.markers:
+            for ma in self.markers:
+                ma.draw()
         # 翻页按钮
         self.draw_t('上一页', (pageback_rect.x+pageback_rect.w/2, pageback_rect.y+pageback_rect.h/2))
         self.draw_t('下一页', (pageforward_rect.x+pageforward_rect.w/2, pageforward_rect.y+pageforward_rect.h/2))
@@ -67,6 +93,8 @@ class Update(fzgpio.Mecanum_wheel):
         self.draw_t('前进速度(mm/s): '+str(round(math.sqrt(fzgpio.msg_dict['actor'][1]['contr_fb']**2 +
                                        fzgpio.msg_dict['actor'][1]['contr_lr']**2), 1)),
                     fzgpio.texts_pos_sitting['前进速度(mm/s): '])
+        # 积分
+        self.draw_t('分数：' + str(self.score), (1050, 678))
 
     # 硬件图像刷新
     def draw_sensors(self):
@@ -109,7 +137,7 @@ class Update(fzgpio.Mecanum_wheel):
         # # 小车右红外绘制
         # screen.draw.circle((int(fzgpio.msg_dict['Hongwai_pos']['hongwai_right_x']),
         #                            int(fzgpio.msg_dict['Hongwai_pos']['hongwai_right_y'])), 20, color=(0, 0, 0))
-        # # IO输入碰撞检测框绘制
+        # IO输入碰撞检测框绘制
         # io_in_x = self.actor.center[0] - (self.actor.width / 2 + 13) * math.sin(math.radians(self.actor.angle))
         # io_in_y = self.actor.center[1] - (self.actor.height / 2 + 13) * math.cos(math.radians(self.actor.angle))
         # io_input_rect = Rect((io_in_x, io_in_y), (10, 10))  # IO输入模式下的碰撞检测矩形
@@ -170,26 +198,34 @@ class Update(fzgpio.Mecanum_wheel):
     # 摄像头获取仿真界面图像
     def cramer_update(self):
         # 图像矩形位置
+        # if self.actor.x > (200 + 130) and self.actor.y > (6 + 130):
         cr_x = self.actor.center[0] - (self.actor.width / 2 + 55) * math.sin(math.radians(self.actor.angle))
         cr_y = self.actor.center[1] - (self.actor.height / 2 + 55) * math.cos(math.radians(self.actor.angle))
         screen_rect = screen.surface.get_rect()  # 屏幕矩形
         shijue_clip = screen_rect.clip((cr_x - 50, cr_y - 50), (100, 100))  # 裁剪矩形
         py_image, image_rect = tools.clip_image(shijue_clip)
         fzimage = tools.change_image(py_image, size=(200, 200))  # cv2类型的图像
-        fzshijue1.dict['fzimage'] = fzimage
+        if self.markers:
+            for key, ot in enumerate(self.markers):
+                ot_rect = Rect((ot.left, ot.top), (ot.width, ot.height))
+                b_rect = fzshijue1.acontainsbs(shijue_clip, ot_rect)
+                if b_rect:
+                    other_front_view = loaders.images.load(self.markers_front_view[key])
+                    fzimage = tools.change_image(other_front_view, size=(200, 200))  # cv2类型的图像
+        fzshijue1.fzcamera_dict['fzimage'] = fzimage
 
     # 小车运动刷新
     def car_update(self):
         if fzgpio.msg_dict['actor'][0] == 1:
-            actor_rect = Rect((self.actor.left+10, self.actor.top+10),
-                              (self.actor.width-20, self.actor.height-20))
+            self.actor_small_rect = Rect((self.actor.left + 10, self.actor.top + 10),
+                                         (self.actor.width - 20, self.actor.height - 20))
             # IO输入模式下的提前碰撞检测框
             io_in_x = self.actor.center[0] - (self.actor.width / 2 + 13) * math.sin(math.radians(self.actor.angle))
             io_in_y = self.actor.center[1] - (self.actor.height / 2 + 13) * math.cos(math.radians(self.actor.angle))
             io_input_rect = Rect((io_in_x, io_in_y), (1, 1))  # IO输入模式下的碰撞检测矩形
             # ---------------------------------------------------------------------------------
             # 中间画面的大小，小车和物体的放置和运动不能超过此界限
-            background_rect = Rect((200, 6), (900, 650))
+            background_rect = Rect(constants.background_rect[0], constants.background_rect[1])
             hongwai_rect = Rect((int(fzgpio.msg_dict['Hongwai_pos']['hongwai_right_x']),
                                  int(fzgpio.msg_dict['Hongwai_pos']['hongwai_right_y'])), (1, 1))
             # ---------------------------------------------------------------------------------
@@ -201,24 +237,23 @@ class Update(fzgpio.Mecanum_wheel):
                     obj.update()
                     # if len(LEVEL.level[2]) > 0:
                     #     for csb_collide in [Rect(i) for i in LEVEL.level[2]]:
-                    #         csb_collide, csb_obj_rect = Collide.A_colliderect_Bs(obj.csb_rect, csb_collide)
+                    #         csb_collide, csb_obj_rect = tools.A_colliderect_Bs(obj.csb_rect, csb_collide)
                     #         if csb_collide == True
             # ---------------------------------------------------------------------------------
             # 检测小车与物体或者边界的碰撞，若碰撞则停止行驶
             if len(LEVEL.level[2]) > 0:
                 for collide_detection in [Rect(i) for i in LEVEL.level[2]]:
-                    # 小车本身与各个指定矩形的碰撞检测
-                    fzgpio.msg_dict['car_collide'], car_obj_rect = Collide.a_collide_rect_bs(actor_rect,
-                                                                                             collide_detection)
                     # 小车扩展矩形与各个指定矩形的碰撞检测
                     fzgpio.msg_dict['car_expansion_collide'], expansion_obj_rect = \
-                        Collide.a_collide_rect_bs(io_input_rect, collide_detection)
+                        tools.a_collide_rect_bs(io_input_rect, collide_detection)
+                    # 小车本身与各个指定矩形的碰撞检测
+                    fzgpio.msg_dict['car_collide'], car_obj_rect = tools.a_collide_rect_bs(self.actor_small_rect,
+                                                                                           collide_detection)
                     # 超声波操作
                     if fzgpio.msg_dict['csbs'][0] == 1:
                         for key, obj in enumerate(fzgpio.msg_dict['csbs'][1]):
                             # 超声波与各个矩形的碰撞检测
-                            csb_collide, csb_obj_rect = Collide.a_collide_rect_bs(obj.csb_rect,
-                                                                                  collide_detection)
+                            csb_collide, csb_obj_rect = tools.a_collide_rect_bs(obj.csb_rect, collide_detection)
                             if not background_rect.contains(obj.csb_rect):
                                 del obj, fzgpio.msg_dict['csbs'][1][key]  # 销毁碰撞后的超声波对象，并把其从list中移除
                                 fzgpio.msg_dict['csbs'][2] = None
@@ -227,11 +262,11 @@ class Update(fzgpio.Mecanum_wheel):
                                 fzgpio.msg_dict['csbs'][2] = tools.distance_ab(self.actor.pos,
                                                                                (obj.csb_rect.x, obj.csb_rect.y))
                                 del obj, fzgpio.msg_dict['csbs'][1][key]  # 销毁碰撞后的超声波对象，并把其从list中移除
-                    if fzgpio.msg_dict['car_collide']:  # 小车如果碰撞
+                    if fzgpio.msg_dict['car_collide'] or fzgpio.msg_dict['car_expansion_collide']:  # 小车如果碰撞
                         break
             else:
                 fzgpio.msg_dict['car_collide'] = False
-            if background_rect.contains(actor_rect) and \
+            if background_rect.contains(self.actor_small_rect) and \
                     background_rect.contains(hongwai_rect) and \
                     (not fzgpio.msg_dict['car_collide']):
                 self.car_contr_run()  # 小车运动，若碰撞则无法执行
@@ -247,6 +282,27 @@ class Update(fzgpio.Mecanum_wheel):
                 print(result)
                 sys.exit(0)
 
+    def score_update(self):
+        if fzgpio.msg_dict['actor'][0] == 1:
+            self.actor_big_rect = Rect((self.actor.left - 10, self.actor.top - 10),
+                                       (self.actor.width + 20, self.actor.height + 20))
+            csb_collide = False
+            if self.stars:
+                for num, star in enumerate(self.stars):
+                    star_rect = Rect((star.x, star.y), (star.width, star.height))
+                    collide_or_not, collided_star_rect = tools.a_collide_rect_bs(self.actor_big_rect, star_rect)
+                    # 此判断用于超声波虚拟场景时的超声波碰撞星星后积分
+                    if fzgpio.msg_dict['csbs'][0] == 1 and LEVEL.level[3][3] == '超声波':
+                        for key, obj in enumerate(fzgpio.msg_dict['csbs'][1]):
+                            csb_collide, csb_obj_rect = tools.a_collide_rect_bs(obj.csb_rect, star_rect)
+                            if csb_collide:
+                                del star, self.stars[num]
+                                self.score += round(100 / len(LEVEL.level[3][1]))
+                    # 小车碰撞星星后积分
+                    elif collide_or_not:
+                        del star, self.stars[num]
+                        self.score += round(100/len(LEVEL.level[3][1]))
+
     # 运行监听
     @staticmethod
     def fzq_over():
@@ -274,7 +330,7 @@ class Update(fzgpio.Mecanum_wheel):
 
 # --------------------------------------------------------------------------------------------------------
 def on_mouse_down(pos, button):
-    # print(pos)
+    print(pos)
     # 点击鼠标右键给右边的硬件展示画面翻页
     if button == 1:
         if pageback_rect.collidepoint(pos[0], pos[1]):
@@ -322,17 +378,21 @@ if run != '':
     def update():
         Update.car_update()
         Update.cramer_update()
+        Update.score_update()
         Update.fzq_over()
     # --------------------------------------------------------------------------------------------------------
     # 设置根路径（也就是仿真所需要的图像路径，此处由change.py写入）
-    # files_path = 'C:\\Users\\86137\\Documents\\python_code\\fzq_test\\files\\'
+    # files_path = 'C:\\Users\\86137\\Documents\\python_code\\fzq_test\\emulator_files\\'
     files_path = ''
     loaders.set_root(files_path)
+    # 获取constants.py文件的位置，并导入
+    sys.path.append(files_path)
+    import constants
     # 关卡设置：
-    LEVEL = levels.Level()
+    LEVEL = constants.Level()
     # 获取储存日志的位置，记录报错内容
-    files_path_logger = tools.path_processing(files_path, -2, 'txt\\')
-    tools.Logging(files_path_logger)
+    # files_path_logger = tools.path_processing(files_path, -2, 'txt\\')
+    tools.Logging(files_path)
     # --------------------------------------------------------------------------------------------------------
     # 窗口设置
     # screen : Screen
@@ -360,12 +420,9 @@ if run != '':
                                    fontsize=18)
     # --------------------------------------------------------------------------------------------------------
     # 翻页框
-    pageback_rect = Rect(1111, 660, 180 / 2, 35)
-    pageforward_rect = Rect(1111 + (180 / 2) + 5, 660, 180 / 2, 35)
+    pageback_rect = Rect(constants.pageback_rect[0], constants.pageback_rect[1])
+    pageforward_rect = Rect(constants.pageforward_rect[0], constants.pageforward_rect[1])
     # --------------------------------------------------------------------------------------------------------
-    # 实例化对象
-    # 碰撞检测器
-    Collide = tools.Collide()
     # 事件刷新
     Update = Update()
     # 启动子线程code（目的：利用子线程控制主线程的仿真画面）
